@@ -4,7 +4,7 @@ import asyncio
 import warnings
 from collections import defaultdict, deque
 from enum import IntEnum
-from typing import List, Dict, Any, AsyncGenerator, Iterable, TypeVar, Generic
+from typing import List, Dict, Any, AsyncGenerator, Iterable, TypeVar, Generic, Tuple, Mapping
 
 from .base import SynchronousPublisher, SynchronousSubscriber, AsyncPublisher, AsyncSubscriber
 
@@ -194,6 +194,8 @@ class AsyncLocalBroker:
         return notifier()
 
     async def subscribe(self, queue_names: List[str]) -> AsyncGenerator:
+        if not queue_names:
+            return
 
         waiters: Dict[asyncio.Task, str] = {}
 
@@ -226,7 +228,7 @@ class AsyncLocalBroker:
                     # yield fetched value
                     result = fut.result()
                     if result is not DROP:
-                        yield result
+                        yield result, q_name
                         self._queues[q_name].task_done()
             except asyncio.CancelledError:
                 for w in waiters.keys():
@@ -321,9 +323,10 @@ class AsyncLocalSubscriber(AsyncSubscriber):
         await self._fetcher.aclose()
         self.logger.debug(f"Subscriber left broker {self._broker}")
 
-    async def _fetch_one(self, timeout: float = None):
+    async def _fetch_one(self, timeout: float = None) -> Tuple[bytes, Mapping]:
         try:
-            return await asyncio.wait_for(self._fetcher.__anext__(), timeout=timeout), {}
+            data, q_name = await asyncio.wait_for(self._fetcher.__anext__(), timeout=timeout)
+            return data, {'queue_name': q_name}
         except AttributeError:
             if not hasattr(self, '_fetcher'):
                 raise RuntimeError(
@@ -341,3 +344,12 @@ class AsyncLocalSubscriber(AsyncSubscriber):
         task = await super().get(timeout=timeout)
         self.uncommitted.add(task.uuid)
         return task
+
+    async def subscribe(self, queue_name: Iterable[str]):
+        raise NotImplementedError('changing subscription on local client is not supported')
+
+    async def unsubscribe(self, queue_name: Iterable[str]):
+        raise NotImplementedError('changing subscription on local client is not supported')
+
+    def subscription(self) -> Iterable[str]:
+        return self.settings.queue_names
