@@ -57,7 +57,7 @@ class ComponentConfig(Generic[ComponentType]):
         if error:
             raise ValidationError([error], cls)
 
-        options_field = getattr(engine.type_, 'Settings', None)
+        options_field = getattr(engine.type_, 'Config', None)
         if options_field is not None:
             opts = options_field.validate(v)
         else:
